# Change Log

## 0.1.3

Released 2021-01-02

- Added Python 3.9 support
- Removed Python 3.5 support

## 0.1.2

Released 2019-12-23

- Added available case style
- Added support for single word input
- Added support for multi-line input
- Removed Python 2.7 support

## 0.1.1

Released 2019-12-22

- Added alias to argument

## 0.1.0

Released 2019-12-21

- Initial release
